"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const databases_1 = require("./utils/databases");
const redis_1 = tslib_1.__importDefault(require("./utils/redis"));
const Fastify = tslib_1.__importStar(require("fastify"));
const elastic_apm_node_1 = tslib_1.__importDefault(require("elastic-apm-node"));
const rabbit_1 = tslib_1.__importDefault(require("./utils/rabbit"));
const logger_1 = tslib_1.__importDefault(require("./utils/logger"));
class Microservice {
    constructor(config) {
        this.agent = elastic_apm_node_1.default.start({
            logLevel: 'trace'
        });
        if (config.databases) {
            databases_1.initDbInstances(this, config.databases);
        }
        if (config.redis) {
            this.redis = new redis_1.default();
        }
        if (config.rabbit) {
            this.rabbit = new rabbit_1.default('amqp://localhost');
        }
        //init MicroService
        this.server = Fastify.fastify({
            logger: true
        });
        this.config = config;
        this.server.get('/', function (request, reply) {
            reply.send({ hello: 'world' });
        });
        this.logger = new logger_1.default();
    }
    declareRoute(verb, path, handler, options) {
        let onRequest = null;
        if (options && options.onRequest)
            onRequest = options.onRequest;
        const apmContextInject = async (req, res) => {
            this.agent.setCustomContext(req);
        };
        if (onRequest) {
            onRequest =
                typeof onRequest === 'function'
                    ? [apmContextInject, onRequest]
                    : [apmContextInject, ...onRequest];
        }
        else {
            onRequest = [apmContextInject];
        }
        this.server.route({
            ...options,
            method: verb,
            url: path,
            handler: handler,
            onRequest: onRequest
        });
    }
    publish(msg, queue) {
        if (this.rabbit)
            this.rabbit.pub(queue, msg);
    }
    log(log) {
        this.logger.log(log);
    }
    error(log, error) {
        this.logger.error(log, error);
    }
    async start() {
        return await this.server
            .listen(this.config.port)
            .then(() => {
            console.log('SERVER LISTENING');
            return true;
        })
            .catch((err) => {
            console.log(err);
            return false;
        });
    }
}
exports.default = Microservice;
