import { Config } from './interfaces/config';
import * as Fastify from 'fastify';
import { Verbs } from './interfaces/common';
import rabbit from './utils/rabbit';
import logger from './utils/logger';
export default class Microservice {
    /**
     * creates an endpoint in the microservice with configs
     *
     * @param server - fastify instance
     * @param config - Microservice config used to initiate it
     * @param agent - AMP agent to register routes
     * @param databases - array of database connection
     * @param rabbit - Rabbit connection
     * @param logger - logger instance
     *
     */
    server: Fastify.FastifyInstance;
    private config;
    private agent;
    databases?: any;
    rabbit?: rabbit;
    logger: logger;
    constructor(config: Config);
    declareRoute(verb: Verbs, path: string, handler: Fastify.RouteHandlerMethod, options?: Fastify.RouteOptions): void;
    publish(msg: string, queue: string): void;
    log(log: string): void;
    error(log: string, error?: number): void;
    start(): Promise<boolean>;
}
