"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initDbInstances = void 0;
const tslib_1 = require("tslib");
const sequelize_typescript_1 = require("sequelize-typescript");
const fs_1 = tslib_1.__importDefault(require("fs"));
const redis_1 = tslib_1.__importDefault(require("./redis"));
const initDbInstances = (service, databases) => {
    /**
     * handler to assign all requested databases to microservice object
     *
     * @param service - the microservice object
     * @param databases - array of database connection objects
     *
     */
    service.databases = [];
    for (const db of databases) {
        switch (db.type) {
            case 'crdb': {
                const name = db.name || db.database;
                service.databases[name] = initCrdb(db);
                break;
            }
            case 'redis':
                service.databases[db.name || 'redis'] = new redis_1.default(db);
                break;
            default:
                console.log('invalid database type');
        }
    }
};
exports.initDbInstances = initDbInstances;
const initCrdb = (db) => {
    /**
     * connectss to database and returns its sequelize object
     *
     * @param service - the microservice object
     * @param databases - array of database connection objects
     *
     * @returns {Sequelize} database object
     *
     */
    const { port, host, database, user, password, certDir, modelsRootDir } = db;
    const config = {
        dialect: 'postgres',
        port: port,
        host: host,
        logging: false,
        models: [modelsRootDir + '/models/**/*.model.js'],
        modelMatch: (filename, member) => {
            return (filename.substring(0, filename.indexOf('.model')) ===
                member.toLowerCase());
        }
    };
    if (certDir) {
        config.dialectOptions = {
            ssl: {
                ca: fs_1.default.readFileSync(certDir + `ca.crt`).toString(),
                key: fs_1.default.readFileSync(certDir + `client.${user}.key`).toString(),
                cert: fs_1.default.readFileSync(certDir + `client.${user}.crt`).toString()
            }
        };
    }
    return new sequelize_typescript_1.Sequelize(database, user || 'default', password || '', config);
};
