"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const ioredis_1 = tslib_1.__importDefault(require("ioredis"));
class redis {
    constructor(options) {
        const { port, host, password, database } = options;
        this.redisConnection = new ioredis_1.default({
            port: port,
            host: host,
            password: password,
            db: database
        });
    }
    get(key, onSuccess, onError) {
        /**
         * gets value from a key
         *
         * @param key - key to query redis
         * @param onSuccess - handler function on successful get
         * @param onError - handler function on failed get
         *
         */
        this.redisConnection.get(key, (err, result) => {
            if (err) {
                onError(err, result);
            }
            else {
                onSuccess(result);
            }
        });
    }
    set(key, data, onSuccess, onError) {
        /**
         * creates a key value pair in redis
         *
         * @param key - key to query redis
         * @param data - value of the key
         * @param onSuccess - handler function on successful get
         * @param onError - handler function on failed get
         *
         */
        this.redisConnection.set(key, data, (err, result) => {
            if (err) {
                onError(err, result);
            }
            else {
                onSuccess(result);
            }
        });
    }
    setnx(key, data, onSuccess, onExists, onError) {
        /**
         * creates a key value pair in redis if key does not have a value
         *
         * @param key - key to query redis
         * @param data - value of the key
         * @param onSuccess - handler function on successful get
         * @param onExists - handler function if the key already has a value
         * @param onError - handler function on failed get
         *
         */
        this.redisConnection.setnx(key, data, (err, result) => {
            if (err) {
                onError(err, data);
            }
            else {
                if (result) {
                    onSuccess(data);
                }
                else {
                    onExists();
                }
            }
        });
    }
}
exports.default = redis;
