"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initDbInstances = void 0;
const tslib_1 = require("tslib");
const sequelize_typescript_1 = require("sequelize-typescript");
const fs_1 = tslib_1.__importDefault(require("fs"));
const initDbInstances = (service, databases) => {
    for (const db of databases) {
        switch (db.type) {
            case 'crdb':
                service.databases[db.database] = initCrdb(db);
                break;
            default:
                console.log('invalid database type');
        }
    }
};
exports.initDbInstances = initDbInstances;
const initCrdb = (db) => {
    const { port, host, database, user, password, certDir, modelDir } = db;
    const config = {
        dialect: 'postgres',
        port: port,
        host: host,
        logging: false,
        models: [modelDir + '/models/**/*.model.js'],
        modelMatch: (filename, member) => {
            return (filename.substring(0, filename.indexOf('.model')) ===
                member.toLowerCase());
        }
    };
    if (certDir) {
        config.dialectOptions = {
            ssl: {
                ca: fs_1.default.readFileSync(certDir + `ca.crt`)
                    .toString(),
                key: fs_1.default.readFileSync(certDir + `client.${user}.key`)
                    .toString(),
                cert: fs_1.default.readFileSync(certDir + `client.${user}.crt`)
                    .toString()
            }
        };
    }
    return new sequelize_typescript_1.Sequelize(database, user, password || '', config);
};
